
% --------------------------------------------------------
% Parameters for BPOP model
%       Elisa Lovecchio 2019 (e.lovecchio@exeter.ac.uk)
% --------------------------------------------------------


% ===== Simulation details

runtitle='BPOP_testrun';  % set simulation name here 

% ===== Biopump details to loop on

% remin lengths
zrem_small_min = 0; % m, approx. remin length of small sinking particles 
zrem_small_max = 40; % m, approx. remin length of small sinking particles 
zrem_large_min = 50; % m, approx. remin length of large sinking particles 
zrem_large_max = 450; % m, approx. remin length of large sinking particles 

dsmall=2;
dlarge=20;

coag_rate = 0.001 * 365.25; % 1/yr Small particle coagulation rate

max_remin_rate = 0.002 * 365.25; % 1/yr Sediment remineralization rate 

% NB: to go back to a 1 sinking Porg type only ("small" type) set the params as follows: 
%     zrem_small = your choice; zrem_large = #unused_whatever; coag_rate = 0;


% ===== Box properties

DeltaZ_eu = 100;  % m (depth of the surface ocean -  euph layer)
DeltaZ_ds = 100;  % m (depth of the deep shelf)
DeltaZ_do = 3500; % m (depth of the deep open ocean)

Ocean_area = 361 *1e12; % m^2 
Shelf_perc = 7; % today shelf seas up to 200 m cover about 7% of the ocean surf (Barron and Duarte, 2015; Wollast, 1998)

Area_shelf = Ocean_area*(Shelf_perc/100); % m^2
Area_openo = Ocean_area*((100-Shelf_perc)/100);% m^2

% - Box volumes 
V_ss = DeltaZ_eu*Area_shelf; % m^3 
V_ds = DeltaZ_ds*Area_shelf; % m^3 
V_so = DeltaZ_eu*Area_openo; % m^3 
V_do = DeltaZ_do*Area_openo; % m^3 

Vol_vec=[V_ss; V_ds; V_so; V_do];
% sums to 1.2137 * 1e+09 km^3, compare to ocean volume data: 1,335,000,000 km^3 ---> O.K.
% V_tot = 1.2137e+18 m^3

% Moles to calculate O2 mixing ratio in atmosphere (atmo pressure > mass > moles)
Mol_atmo = 1.8 * 10^20; % Moles in atmospheric box [mol]
mmol_atmo = Mol_atmo * 10^3; % millimoles in atmospheric box [mol]

% ===== Time 

t_simu = 70*1e6; % total simulation time in years 

spy = 3600 * 24 * 365.25; % seconds per year

% ===== Initial values

PO4_ini = 2.2; % muM = mu_mol/L = mmol/m^3
% Typical PO4 values in the open ocean are between 0 and 3 muM

O2_ini = 0; % muM = mu_mol/L = mmol/m^3 (assuming ocean is not oxygenated at the beginning)
% NB: Typical O2 values in the open ocean are between 20 and 200 muM - <60 hypoxia, <5 suboxia


% ===== Mixing/advection between boxes [in units of m^3 per year (or dt)]

Mix = 40 * 1e6 * spy; % (mixing in open ocean)
Upw = 5.5 * 1e6 * spy; % (upwelling cell circulation between shelf and open ocean)
              
SS_mix = 1.5 * 1e6 * spy; % (surf shelf lateral mixing) 
DS_mix = 1.5 * 1e6 * spy; % (deep shelf lateral mixing)
VS_mix = 0.5 * 1e6 * spy; % (vertical mixing in shelf) 

LatFlx_ss = (Upw+SS_mix);
LatFlx_ds = DS_mix;

% ===== River input flux  

P_riv = 0.092; % input from rivers in Tmol/yr = 10^12 mol/yr (Slomp & Von Cappellen)
P_riv_in = P_riv * 1e12 * 1000; % in mmol/yr

P_frac_so = 0.4; % fraction of P delivered to open waters (low estim.) - NB: about 70% of P reaches the open ocean --> https://agupubs.onlinelibrary.wiley.com/doi/full/10.1002/2016GB005483


% ===== Bio parameters and input flux

P_up_max = 0.8; % max P uptake 1/yr 
Ks_P = 0.2; % Michaelis menten 1/2 constant for P uptake

OP_redf = 106; % C:P ratio, assuming C:O_2=1
K_O2 = 2; % muM = mmol/m^3 (using the M-M as a switch from anaerobic and aerobic respiration, most models switch at 4 mmol/m^3, data show lower values)


% ===== Gas transfer params (O2)

% NB: all the following is from Sarmiento Gruber 2006
T_mean = 17.64; % degC (global mean temperature)
W_speed = 7.5; % m/s (global mean wind speed)                    % below: Keeling et al 1998

N_sch = 1638 - 81.83*T_mean +1.483*T_mean^2 - 0.008004*T_mean^3; % Schmidt number for a salinity of 35 

K_w = 0.31 * W_speed^2 * (660/N_sch)^0.5; % cm/h -> Gas transfer velocity Wanninkof 1992 
K_w_myr = K_w * 10^(-2) * (24*365.25); % m/yr 

K_Henri = 770 * 10^(-6); % L*atm/mol --> m^3*atm/mmol (converts partial pressure to dissolved concentration)


% ===== Oxy Weathering params

O2mix_now = 0.21; % current value
Wox0_mmol = (P_riv * 1e12 * 1000) * OP_redf; % baseline oxidative weathering flux


% ===== CaP formation rate

CaP_rate_mmol = 0.2; % 1/yr rate of Ca-P formation 



